#
# Double click on this on Windows systems to run the installer!!
#
source [file join installer install.tcl]
